Editor Test: FullScreen Plugin

Content before the editor.

# Full Screen Plugin details

1. The Fullscreen plugin provides an extra button on the toolbar to allow switching the editor into 'full screen' mode, meaning the editor takes over the viewport of the browser. This plugin is particularly useful when editing large documents.
2. The mode can also be toggled by entering the key command: CTRL-SHIFT-F11 in the editor pane.
3. When it toggled to full screen, it makes the editor text pane opaque white so that the contents behind it are not visible.
4. When in full screen mode, the plugin attempts to capture the TAB key and allow navigation only between the editor toolbar and the editing area, as when in full screen mode, the rest of the page is hidden behind the editor.

## Things to test:

1. Verify that clicking the full screen icon highlights the button appropriately and toggles the full screen mode on.
2. Verify that clicking the full screen icon again dehighlites the button and toggles the full screen mode off.
3. Click in the editing pane and verify that CTRL-SHIFT-F11 toggles the full screen mode on and off.
4. Verify while in full screen mode that TAB seems to behave appropriately. Please note that FireFox and Internet Explorer work the best here. There are still a few tab control issues in Safari and Chrome.

Content after the editor.

# BorderContainer with center region containing editor.

left
top
right
bottom

# Full Screen Plugin details

1. The Fullscreen plugin provides an extra button on the toolbar to allow switching the editor into 'full screen' mode, meaning the editor takes over the viewport of the browser. This plugin is particularly useful when editing large documents.
2. The mode can also be toggled by entering the key command: CTRL-SHIFT-F11 in the editor pane.
3. When it toggled to full screen, it makes the editor text pane opaque white so that the contents behind it are not visible.
4. When in full screen mode, the plugin attempts to capture the TAB key and allow navigation only between the editor toolbar and the editing area, as when in full screen mode, the rest of the page is hidden behind the editor.

## Things to test:

1. Verify that clicking the full screen icon highlights the button appropriately and toggles the full screen mode on.
2. Verify that clicking the full screen icon again dehighlites the button and toggles the full screen mode off.
3. Click in the editing pane and verify that CTRL-SHIFT-F11 toggles the full screen mode on and off.
4. Verify while in full screen mode that TAB seems to behave appropriately. Please note that FireFox and Internet Explorer work the best here. There are still a few tab control issues in Safari and Chrome.

# TabContainer with tab containing editor.

# Full Screen Plugin details

1. The Fullscreen plugin provides an extra button on the toolbar to allow switching the editor into 'full screen' mode, meaning the editor takes over the viewport of the browser. This plugin is particularly useful when editing large documents.
2. The mode can also be toggled by entering the key command: CTRL-SHIFT-F11 in the editor pane.
3. When it toggled to full screen, it makes the editor text pane opaque white so that the contents behind it are not visible.
4. When in full screen mode, the plugin attempts to capture the TAB key and allow navigation only between the editor toolbar and the editing area, as when in full screen mode, the rest of the page is hidden behind the editor.

## Things to test:

1. Verify that clicking the full screen icon highlights the button appropriately and toggles the full screen mode on.
2. Verify that clicking the full screen icon again dehighlites the button and toggles the full screen mode off.
3. Click in the editing pane and verify that CTRL-SHIFT-F11 toggles the full screen mode on and off.
4. Verify while in full screen mode that TAB seems to behave appropriately. Please note that FireFox and Internet Explorer work the best here. There are still a few tab control issues in Safari and Chrome.

# AccordionContainer with pane containing editor.

# Full Screen Plugin details

1. The Fullscreen plugin provides an extra button on the toolbar to allow switching the editor into 'full screen' mode, meaning the editor takes over the viewport of the browser. This plugin is particularly useful when editing large documents.
2. The mode can also be toggled by entering the key command: CTRL-SHIFT-F11 in the editor pane.
3. When it toggled to full screen, it makes the editor text pane opaque white so that the contents behind it are not visible.
4. When in full screen mode, the plugin attempts to capture the TAB key and allow navigation only between the editor toolbar and the editing area, as when in full screen mode, the rest of the page is hidden behind the editor.

## Things to test:

1. Verify that clicking the full screen icon highlights the button appropriately and toggles the full screen mode on.
2. Verify that clicking the full screen icon again dehighlites the button and toggles the full screen mode off.
3. Click in the editing pane and verify that CTRL-SHIFT-F11 toggles the full screen mode on and off.
4. Verify while in full screen mode that TAB seems to behave appropriately. Please note that FireFox and Internet Explorer work the best here. There are still a few tab control issues in Safari and Chrome.

# StackContainer with pane containing editor.

# Full Screen Plugin details

1. The Fullscreen plugin provides an extra button on the toolbar to allow switching the editor into 'full screen' mode, meaning the editor takes over the viewport of the browser. This plugin is particularly useful when editing large documents.
2. The mode can also be toggled by entering the key command: CTRL-SHIFT-F11 in the editor pane.
3. When it toggled to full screen, it makes the editor text pane opaque white so that the contents behind it are not visible.
4. When in full screen mode, the plugin attempts to capture the TAB key and allow navigation only between the editor toolbar and the editing area, as when in full screen mode, the rest of the page is hidden behind the editor.

## Things to test:

1. Verify that clicking the full screen icon highlights the button appropriately and toggles the full screen mode on.
2. Verify that clicking the full screen icon again dehighlites the button and toggles the full screen mode off.
3. Click in the editing pane and verify that CTRL-SHIFT-F11 toggles the full screen mode on and off.
4. Verify while in full screen mode that TAB seems to behave appropriately. Please note that FireFox and Internet Explorer work the best here. There are still a few tab control issues in Safari and Chrome.